init: move asmap code earlier in init process

and update feature_asmap.py and test_runner.py

This commit moves the asmap init.cpp code from the end of "Step 12: start node"
to "Step 6: network initialization" to provide feedback on passing an -asmap
config arg much more quickly. This change speeds up the feature_asmap.py
functional test file from 60 to 5 seconds by accelerating the 2 tests that use
`assert_start_raises_init_error`.

Credit to Wladimir J. van der Laan for the suggestion.
This commit is contained in:
Jon Atack committed 2020-03-04 14:54:30 +01:00
1 parent 5ba829e12e
commit 1ba3e1cc21
3 files changed
+27 -28

No files matched your search

+1 -2
View File
@@ -18,8 +18,7 @@ Verify node behaviour and debug log when launching bitcoind in these cases:
6. `bitcoind -asmap` with an empty (unparsable) default asmap file
The tests are order-independent. The slowest tests (missing default asmap and
empty asmap) are placed last.
The tests are order-independent.
"""
import os